@@ -1,5 +1,5 @@
-"""
-Test configuration.
+"""Test configuration.
+
 Copyright (c) Reuben Thomas 2023.
 Released under the GPL version 3, or (at your option) any later version.
 """
