@@ -1,17 +1,18 @@
-"""
-includeres tests.
+"""includeres tests.
+
 Copyright (c) Reuben Thomas 2023.
 Released under the GPL version 3, or (at your option) any later version.
 """
 
+from collections.abc import Callable
 from pathlib import Path
-from typing import Callable, List
 
-from pytest import mark, CaptureFixture
+from pytest import CaptureFixture, mark
+from testutils import Case, file_test, make_tests
 
-from testutils import file_test, make_tests, Case
 from psutils.command.includeres import includeres
 
+
 FIXTURE_DIR = Path(__file__).parent.resolve() / "test-files"
 
 pytestmark = make_tests(
@@ -30,9 +31,8 @@ pytestmark = make_tests(
     FIXTURE_DIR / "includeres" / "sample" / "a2ps-a2ps-hdr2.02.ps",
     FIXTURE_DIR / "includeres" / "sample" / "a2ps-black+white-Prolog2.01.ps",
 )
-# pylint: disable=similarities
 def test_includeres(
-    function: Callable[[List[str]], None],
+    function: Callable[[list[str]], None],
     case: Case,
     fixture_dir: Path,
     capsys: CaptureFixture[str],
