@@ -1,17 +1,18 @@
-"""
-pdfnup tests.
-Copyright (c) Reuben Thomas 2023.
+"""pdfnup tests.
+
+Copyright (c) Reuben Thomas 2023-2025.
 Released under the GPL version 3, or (at your option) any later version.
 """
 
+from collections.abc import Callable
 from pathlib import Path
-from typing import List, Callable
 
 from pytest import CaptureFixture
+from testutils import Case, file_test, make_tests
 
-from testutils import file_test, make_tests, Case
 from psutils.command.psnup import psnup
 
+
 pytestmark = make_tests(
     psnup,
     Path(__file__).parent.resolve() / "test-files",
@@ -24,7 +25,7 @@ pytestmark = make_tests(
 
 
 def test_pdfnup(
-    function: Callable[[List[str]], None],
+    function: Callable[[list[str]], None],
     case: Case,
     fixture_dir: Path,
     capsys: CaptureFixture[str],
